==> rnv-0.37.0-rc.11.tgz: package/README.md <==
<p align="center">
  <a href="https://renative.org">
    <img src="https://renative.org/img/renative-logo-framed.png?raw=true" height="128" width="128">
    <h1 align="center">ReNative</h1>
  </a>
  <p align="center">Unified Development Platform</p>
    <p align="center">💻📱⌚📺🖥️</p>
  
</p>

<p align="center">
  <a aria-label="NPM version" href="https://www.npmjs.com/package/renative">
    <img alt="" src="https://img.shields.io/npm/v/renative.svg?style=for-the-badge&labelColor=000000">
  </a>
  <a aria-label="License" href="https://github.com/flexn-io/renative/blob/main/license.md">
    <img alt="" src="https://img.shields.io/npm/l/renative.svg?style=for-the-badge&labelColor=000000">
  </a>
  <a aria-label="Join the community on GitHub" href="https://github.com/flexn-io/renative/discussions">
    <img alt="" src="https://img.shields.io/badge/Join%20the%20community-blueviolet.svg?style=for-the-badge&logo=ReNative&labelColor=000000&logoWidth=20">
  </a>
</p>

ReNative allows you to bootstrap, develop and deploy apps for mobile, web, TVs, desktops, consoles, wearables and more via single development environment.

Supports popular front-end frameworks like [React](https://reactjs.org/), [React Native](https://reactnative.dev/), [NextJS](https://nextjs.org/), [Electron](https://www.electronjs.org/)

## Usage

To install the latest version of ReNative CLI run this command:

```
npm i -g rnv
```

To start new project, run following command:

```
rnv new
```

## Getting Started

Visit [here](https://renative.org/docs/overview/quickstart) to get started with ReNative.

## Documentation

Visit [here](https://renative.org/docs/overview/introduction) to view full documentation.

Documentation source code can be found at https://github.com/flexn-io/renative-docs

## Community

ReNative community can be found on <a aria-label="ReNative Discussions" href="https://github.com/flexn-io/renative/discussions">Github Discussions</a>.

## Core Maintainers

-   Pavel Jacko ([@pavjacko](https://twitter.com/pavjacko)) - https://github.com/pavjacko
-   Mihai Blaga ([@blaga_mihai](https://twitter.com/blaga_mihai)) - https://github.com/mihaiblaga89

## Contributors

Thanks to all contributors [[Contribute]](CONTRIBUTING.md).

<a href="https://github.com/flexn-io/renative/graphs/contributors"><img src="https://opencollective.com/renative/contributors.svg?width=890" /></a>

## Backers

Thank you to all our backers! 🙏 [[Become a backer](https://opencollective.com/renative#backer)]

<a href="https://opencollective.com/renative#backers" target="_blank"><img src="https://opencollective.com/renative/backers.svg?width=890"></a>

==> rnv-1.4.0.tgz: package/README.md <==
<p align="center">
  <a href="https://renative.org">
    <img src="https://renative.org/img/renative-logo-framed.png?raw=true" height="128" width="128" />
    <h1 align="center">ReNative</h1>
  </a>
  <p align="center">Unified Development Platform</p>
    <p align="center">💻📱⌚📺🖥️</p>
  
</p>

<p align="center">
  <a aria-label="NPM version" href="https://www.npmjs.com/package/renative">
    <img alt="" src="https://img.shields.io/npm/v/renative.svg?style=for-the-badge&labelColor=000000" />
  </a>
  <a aria-label="License" href="https://github.com/flexn-io/renative/blob/main/license.md">
    <img alt="" src="https://img.shields.io/npm/l/renative.svg?style=for-the-badge&labelColor=000000" />
  </a>
  <a aria-label="Join the community on GitHub" href="https://github.com/flexn-io/renative/discussions">
    <img alt="" src="https://img.shields.io/badge/Join%20the%20community-blueviolet.svg?style=for-the-badge&logo=ReNative&labelColor=000000&logoWidth=20" />
  </a>
</p>

ReNative allows you to bootstrap, develop and deploy apps for mobile, web, TVs, desktops, consoles, wearables and more via single development environment.

Supports popular front-end frameworks like [React](https://reactjs.org/), [React Native](https://reactnative.dev/), [NextJS](https://nextjs.org/), [Electron](https://www.electronjs.org/)

## Usage

To install the latest version of ReNative CLI run this command:

```
npm i -g rnv
```

To start new project, run following command:

```
rnv new
```

## Getting Started

Visit [here](https://renative.org/docs/overview/quickstart) to get started with ReNative.

## Documentation

Visit [here](https://renative.org/docs/overview/introduction) to view full documentation.

Documentation source code can be found at https://github.com/flexn-io/renative-docs

## Community

ReNative community can be found on <a aria-label="ReNative Discussions" href="https://github.com/flexn-io/renative/discussions">Github Discussions</a>.

## Core Maintainers

-   Pavel Jacko ([@pavjacko](https://twitter.com/pavjacko)) - https://github.com/pavjacko
-   Mihai Blaga ([@blaga_mihai](https://twitter.com/blaga_mihai)) - https://github.com/mihaiblaga89

## Contributors

Thanks to all contributors [[Contribute]](CONTRIBUTING.md).

<a href="https://github.com/flexn-io/renative/graphs/contributors"><img src="https://opencollective.com/renative/contributors.svg?width=890" /></a>

## Backers

Thank you to all our backers! 🙏 [[Become a backer](https://opencollective.com/renative#backer)]

<a href="https://opencollective.com/renative#backers" target="_blank"><img src="https://opencollective.com/renative/backers.svg?width=890" /></a>
